@@ -14,14 +14,12 @@ import operator
 import uuid
 from typing import Any, Mapping, MutableMapping, Sequence, TypeVar
 
-import ibis
 import ibis.expr.datatypes as dt
 import ibis.expr.operations as ops
 import ibis.expr.schema as sch
 import ibis.expr.types as ir
 import toolz
 from ibis import util
-from packaging import version
 
 from ..proto.substrait.ibis import algebra_pb2 as stalg
 from ..proto.substrait.ibis import type_pb2 as stt
@@ -461,17 +459,15 @@ def _translate_window_bounds(
     return translate_preceding(*preceding), translate_following(*following)
 
 
-if version.parse(ibis.__version__) >= version.parse("3.0.0"):
-
-    @translate.register(ops.Alias)
-    def alias_op(
-        op: ops.Alias,
-        expr: ir.ValueExpr,
-        compiler: SubstraitCompiler,
-        **kwargs: Any,
-    ) -> stalg.Expression:
-        # For an alias, dispatch on the underlying argument
-        return translate(op.arg.op(), op.arg, compiler, **kwargs)
+@translate.register(ops.Alias)
+def alias_op(
+    op: ops.Alias,
+    expr: ir.ValueExpr,
+    compiler: SubstraitCompiler,
+    **kwargs: Any,
+) -> stalg.Expression:
+    # For an alias, dispatch on the underlying argument
+    return translate(op.arg.op(), op.arg, compiler, **kwargs)
 
 
 @translate.register(ops.ValueOp)
